@@ -66,6 +66,27 @@ NSString *kMLFileTypeAudio = @"audio";
     return movies;
 }
 
++ (NSArray *)fileForURL:(NSString *)url;
+{
+    NSFetchRequest *request = [[NSFetchRequest alloc] init];
+    NSManagedObjectContext *moc = [[MLMediaLibrary sharedMediaLibrary] managedObjectContext];
+    NSEntityDescription *entity = [NSEntityDescription entityForName:@"File" inManagedObjectContext:moc];
+    [request setEntity:entity];
+    [request setPredicate:[NSPredicate predicateWithFormat:@"url == %@", url]];
+
+    NSSortDescriptor *descriptor = [[NSSortDescriptor alloc] initWithKey:@"title" ascending:YES selector:@selector(localizedCaseInsensitiveCompare:)];
+    [request setSortDescriptors:@[descriptor]];
+
+    NSError *error;
+    NSArray *files = [moc executeFetchRequest:request error:&error];
+    [request release];
+    [descriptor release];
+    if (!files)
+        APLog(@"WARNING: %@", error);
+
+    return files;
+}
+
 - (BOOL)isKindOfType:(NSString *)type
 {
     return [self.type isEqualToString:type];
@@ -86,6 +107,7 @@ NSString *kMLFileTypeAudio = @"audio";
 {
     return [self isKindOfType:kMLFileTypeAudio];
 }
+
 - (BOOL)isSupportedAudioFile
 {
     NSUInteger options = NSRegularExpressionSearch | NSCaseInsensitiveSearch;
@@ -170,28 +192,10 @@ NSString *kMLFileTypeAudio = @"audio";
 @dynamic artist;
 @dynamic album;
 @dynamic albumTrackNumber;
+@dynamic folderTrackNumber;
 @dynamic genre;
 @dynamic albumTrack;
-
-- (NSNumber *)unread
-{
-    [self willAccessValueForKey:@"unread"];
-    NSNumber *ret = [self primitiveValueForKey:@"unread"];
-    [self didAccessValueForKey:@"unread"];
-    return ret;
-}
-
-- (void)setUnread:(NSNumber *)unread
-{
-    @try {
-        [self willChangeValueForKey:@"unread"];
-        [self setPrimitiveValue:unread forKey:@"unread"];
-        [self didChangeValueForKey:@"unread"];
-    }
-    @catch (NSException *exception) {
-        APLog(@"setUnread raised exception");
-    }
-}
+@dynamic unread;
 
 - (NSNumber *)lastPosition
 {
