@@ -37,6 +37,7 @@ extern NSString *kMLFileTypeAudio;
 @interface MLFile :  NSManagedObject
 
 + (NSArray *)allFiles;
++ (NSArray *)fileForURL:(NSString *)url;
 
 - (BOOL)isKindOfType:(NSString *)type;
 - (BOOL)isMovie;
@@ -70,6 +71,7 @@ extern NSString *kMLFileTypeAudio;
 @property (nonatomic, retain) NSString *artist;
 @property (nonatomic, retain) NSString *album;
 @property (nonatomic, retain) NSNumber *albumTrackNumber;
+@property (nonatomic, retain) NSNumber *folderTrackNumber;
 @property (nonatomic, retain) NSString *genre;
 @property (nonatomic, retain) MLAlbumTrack *albumTrack;
 
